@@ -32,10 +32,7 @@ import cdktf._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdktf/tf-module-stack",
-    "6.0.23",
-    __name__[0:-6],
-    "tf-module-stack@6.0.23.jsii.tgz",
+    "@cdktf/tf-module-stack", "7.0.2", __name__[0:-6], "tf-module-stack@7.0.2.jsii.tgz"
 )
 
 __all__ = [
